# 开源之夏 2025

**开源之夏**是由中国科学院软件研究所“开源软件供应链点亮计划”发起并长期支持的一项暑期开源活动，旨在鼓励在校学生积极参与开源软件的开发维护，培养和发掘更多优秀的开发者，促进优秀开源软件社区的蓬勃发展，助力开源软件供应链建设。具体活动信息请参考 [开源之夏官网](https://summer-ospp.ac.cn/)。

AstrBot 社区有幸作为开源社区参与了本次活动，下面列出了目前我们已经发布的项目，欢迎感兴趣的同学们参与。

## 插件数据存储逻辑优化

目前，AstrBot 插件系统在数据存储方面缺乏一致的架构。部分插件使用 SharedPreference 存储机制和 JSON 格式进行数据持久化。这种多样化的存储方式导致了存储逻辑的不统一，既影响了数据的安全性，也增加了插件间的兼容性问题。此外，缺乏标准化的接口使得插件的数据存储和访问方式各异，给系统的维护和扩展带来挑战。本项目旨在重构当前存储方案，引入更安全且高效的数据存储机制，并设计一个统一的插件数据接口模型，规范插件的数据存储与访问，提升系统的安全性、可扩展性和可维护性，为未来插件的开发与管理提供坚实基础。

**项目链接**：[插件数据存储逻辑优化](https://summer-ospp.ac.cn/org/prodetail/253550342?lang=zh&list=pro)

**难度**：进阶

**导师**：[Soulter](https://github.com/Soulter)

**期望完成时间**：210 小时

**项目产出要求**：

1. 设计并实现统一且高效的插件数据存储接口模型，规范插件的数据存储；
2. 重构当前 SharedPreference 的存储逻辑，采用更安全的存储方式；
3. 补充相关技术文档。

**项目技术要求**：

1. 熟悉 Python、Javascript 语言及 asyncio 异步编程技术；
2. 熟悉 SQLite 等关系型数据库相关开发；
3. 熟悉 AstrBot 框架及插件开发。

**成果仓库**：[https://github.com/AstrBotDevs/AstrBot](https://github.com/AstrBotDevs/AstrBot)
